Index: tests/language_2/unresolved_top_level_var_test.dart |
diff --git a/tests/language/unresolved_top_level_var_negative_test.dart b/tests/language_2/unresolved_top_level_var_test.dart |
similarity index 64% |
rename from tests/language/unresolved_top_level_var_negative_test.dart |
rename to tests/language_2/unresolved_top_level_var_test.dart |
index 589ddd5e6c1ddabf5de17631a9c54849d83a78b1..daf5305017ca3cd0d4ebc5ed04eafd957a9f2eb2 100644 |
--- a/tests/language/unresolved_top_level_var_negative_test.dart |
+++ b/tests/language_2/unresolved_top_level_var_test.dart |
@@ -2,11 +2,11 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE file. |
-// Test that an unresolved identifier at the top level does not crash |
-// the parser. |
+// Test that an unresolved identifier at the top level causes a compile-time |
+// error. |
-var a = b; |
+var a = b; /*@compile-error=unspecified*/ |
main() { |
print(a); |
-} |
+} |